==> tao-react-components-1.0.37.tgz: package/lib/stories/index.js <==
'use strict';

var _Button = require('../components/Button');

var _Button2 = _interopRequireDefault(_Button);

var _HeaderBarButton = require('../components/HeaderBarButton');

var _HeaderBarButton2 = _interopRequireDefault(_HeaderBarButton);

var _ContentEditable = require('../components/ContentEditable');

var _ContentEditable2 = _interopRequireDefault(_ContentEditable);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _storybook = require('@kadira/storybook');

require('./style.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _storybook.storiesOf)('Button', module).add('with text', function () {
  return _react2.default.createElement(_Button2.default, null);
});

(0, _storybook.storiesOf)('HeaderBarButton', module).add('theme button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'theme',
    buttonTitle: 'Theme',
    buttonColor: 'HeaderBarButton-Red' });
}).add('share button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'share',
    buttonTitle: 'Share',
    buttonColor: 'HeaderBarButton-Yellow' });
}).add('view button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'view',
    buttonTitle: 'View',
    buttonColor: 'HeaderBarButton-Green' });
}).add('save button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'save',
    buttonTitle: 'Save',
    buttonColor: 'HeaderBarButton-Blue' });
});

(0, _storybook.storiesOf)('ContentEditable', module).addDecorator(function (story) {
  return _react2.default.createElement(
    'div',
    { style: { backgroundColor: 'black', width: '100%', height: '100vh', display: 'flex', justifyContent: 'center', alignItems: 'center' } },
    story()
  );
}).add('ContentEditable', function () {
  return _react2.default.createElement(_ContentEditable2.default, {
    SavedEditorState: {},
    placeholder: 'Write your title here...',
    className: 'Story-ContentEditable' });
});

==> tao-react-components-1.0.39.tgz: package/lib/stories/index.js <==
'use strict';

var _Button = require('../components/Button');

var _Button2 = _interopRequireDefault(_Button);

var _HeaderBarButton = require('../components/HeaderBarButton');

var _HeaderBarButton2 = _interopRequireDefault(_HeaderBarButton);

var _ContentEditable = require('../components/ContentEditable');

var _ContentEditable2 = _interopRequireDefault(_ContentEditable);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _storybook = require('@kadira/storybook');

require('./style.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _storybook.storiesOf)('Button', module).add('with text', function () {
  return _react2.default.createElement(_Button2.default, null);
});

(0, _storybook.storiesOf)('HeaderBarButton', module).add('theme button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'theme',
    buttonTitle: 'Theme',
    buttonColor: 'HeaderBarButton-Red' });
}).add('share button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'share',
    buttonTitle: 'Share',
    buttonColor: 'HeaderBarButton-Yellow' });
}).add('view button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'view',
    buttonTitle: 'View',
    buttonColor: 'HeaderBarButton-Green' });
}).add('save button', function () {
  return _react2.default.createElement(_HeaderBarButton2.default, {
    buttonType: 'save',
    buttonTitle: 'Save',
    buttonColor: 'HeaderBarButton-Blue' });
});

(0, _storybook.storiesOf)('ContentEditable', module).addDecorator(function (story) {
  return _react2.default.createElement(
    'div',
    { style: { backgroundColor: '#f1f1f1', width: '100%', height: '100vh', display: 'flex', justifyContent: 'center', alignItems: 'center' } },
    story()
  );
}).add('ContentEditable', function () {
  return _react2.default.createElement(_ContentEditable2.default, {
    SavedEditorState: {},
    placeholder: 'Write your title here...',
    className: 'Story-ContentEditable' });
});
